==> api-vertx-client-0.7.20.6.1-sources.jar: io/nem/sdk/openapi/vertx/api/rxjava/NodeRoutesApi.java <==
package io.nem.sdk.openapi.vertx.api.rxjava;

import io.nem.sdk.openapi.vertx.model.NodeInfoDTO;
import io.nem.sdk.openapi.vertx.model.NodeTimeDTO;

import java.util.*;

import rx.Single;
import io.vertx.core.AsyncResult;
import io.vertx.core.Handler;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2020-01-01T18:24:23.294947664-03:00[America/Argentina/Buenos_Aires]")
public class NodeRoutesApi {

	private final io.nem.sdk.openapi.vertx.api.NodeRoutesApi delegate;

	public NodeRoutesApi(io.nem.sdk.openapi.vertx.api.NodeRoutesApi delegate) {
	    this.delegate = delegate;
    }

	public io.nem.sdk.openapi.vertx.api.NodeRoutesApi getDelegate() {
	    return delegate;
	}

    /**
     * Get the node information
     * Supplies additional information about the application running on a node.
     * @param resultHandler Asynchronous result handler
     */
    public void getNodeInfo(Handler<AsyncResult<NodeInfoDTO>> resultHandler) {
        delegate.getNodeInfo(resultHandler);
    }

    /**
     * Get the node information
     * Supplies additional information about the application running on a node.
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<NodeInfoDTO> rxGetNodeInfo() {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNodeInfo(fut);
        }));
    }
    /**
     * Get the node time
     * Gets the node time at the moment the reply was sent and received.
     * @param resultHandler Asynchronous result handler
     */
    public void getNodeTime(Handler<AsyncResult<NodeTimeDTO>> resultHandler) {
        delegate.getNodeTime(resultHandler);
    }

    /**
     * Get the node time
     * Gets the node time at the moment the reply was sent and received.
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<NodeTimeDTO> rxGetNodeTime() {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNodeTime(fut);
        }));
    }

    public static NodeRoutesApi newInstance(io.nem.sdk.openapi.vertx.api.NodeRoutesApi arg) {
        return arg != null ? new NodeRoutesApi(arg) : null;
    }
}

==> api-vertx-client-0.7.21-sources.jar: io/nem/sdk/openapi/vertx/api/rxjava/NodeRoutesApi.java <==
package io.nem.sdk.openapi.vertx.api.rxjava;

import io.nem.sdk.openapi.vertx.model.NodeInfoDTO;
import io.nem.sdk.openapi.vertx.model.NodeTimeDTO;

import java.util.*;

import rx.Single;
import io.vertx.core.AsyncResult;
import io.vertx.core.Handler;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2019-11-23T10:26:45.594287+01:00[Europe/Madrid]")
public class NodeRoutesApi {

	private final io.nem.sdk.openapi.vertx.api.NodeRoutesApi delegate;

	public NodeRoutesApi(io.nem.sdk.openapi.vertx.api.NodeRoutesApi delegate) {
	    this.delegate = delegate;
    }

	public io.nem.sdk.openapi.vertx.api.NodeRoutesApi getDelegate() {
	    return delegate;
	}

    /**
     * Get the node information
     * Supplies additional information about the application running on a node.
     * @param resultHandler Asynchronous result handler
     */
    public void getNodeInfo(Handler<AsyncResult<NodeInfoDTO>> resultHandler) {
        delegate.getNodeInfo(resultHandler);
    }

    /**
     * Get the node information
     * Supplies additional information about the application running on a node.
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<NodeInfoDTO> rxGetNodeInfo() {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNodeInfo(fut);
        }));
    }
    /**
     * Get the node time
     * Gets the node time at the moment the reply was sent and received.
     * @param resultHandler Asynchronous result handler
     */
    public void getNodeTime(Handler<AsyncResult<NodeTimeDTO>> resultHandler) {
        delegate.getNodeTime(resultHandler);
    }

    /**
     * Get the node time
     * Gets the node time at the moment the reply was sent and received.
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<NodeTimeDTO> rxGetNodeTime() {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getNodeTime(fut);
        }));
    }

    public static NodeRoutesApi newInstance(io.nem.sdk.openapi.vertx.api.NodeRoutesApi arg) {
        return arg != null ? new NodeRoutesApi(arg) : null;
    }
}
